@@ -72,7 +72,10 @@ class H2OGBM(H2OGBMParams, H2OTreeBasedSupervisedAlgorithm, DistributionBasedH2O
                  minSplitImprovement=1.0E-5,
                  histogramType="AUTO",
                  calibrateModel=False,
+                 calibrationMethod="AUTO",
                  checkConstantResponse=True,
+                 inTrainingCheckpointsDir=None,
+                 inTrainingCheckpointsTreeInterval=1,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
