@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OTreeBasedUnsupervisedAlgorithm import H2OTreeBasedUnsupervisedAlgorithm
 from ai.h2o.sparkling.ml.models.H2OIsolationForestMOJOModel import H2OIsolationForestMOJOModel
@@ -28,11 +28,13 @@ class H2OIsolationForest(H2OIsolationForestParams, H2OTreeBasedUnsupervisedAlgor
 
     @keyword_only
     def __init__(self,
+                 ignoredCols=None,
                  calibrationDataFrame=None,
                  validationLabelCol="label",
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -43,7 +45,6 @@ class H2OIsolationForest(H2OIsolationForestParams, H2OTreeBasedUnsupervisedAlgor
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  sampleSize=256,
                  sampleRate=-1.0,
                  mtries=-1,
@@ -58,7 +59,6 @@ class H2OIsolationForest(H2OIsolationForestParams, H2OTreeBasedUnsupervisedAlgor
                  scoreTreeInterval=0,
                  modelId=None,
                  categoricalEncoding="AUTO",
-                 ignoredCols=None,
                  ignoreConstCols=True,
                  scoreEachIteration=False,
                  stoppingRounds=0,
