@@ -75,6 +75,11 @@ class H2OGBMMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneConstrai
         return value
 
 
+    def getInteractionConstraints(self):
+        value = self._java_obj.getInteractionConstraints()
+        return H2OTypeConverters.scala2DArrayToPython2DArray(value)
+
+
     def getBalanceClasses(self):
         value = self._java_obj.getBalanceClasses()
         return value
@@ -165,11 +170,26 @@ class H2OGBMMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneConstrai
         return value
 
 
+    def getCalibrationMethod(self):
+        value = self._java_obj.getCalibrationMethod()
+        return value
+
+
     def getCheckConstantResponse(self):
         value = self._java_obj.getCheckConstantResponse()
         return value
 
 
+    def getInTrainingCheckpointsDir(self):
+        value = self._java_obj.getInTrainingCheckpointsDir()
+        return value
+
+
+    def getInTrainingCheckpointsTreeInterval(self):
+        value = self._java_obj.getInTrainingCheckpointsTreeInterval()
+        return value
+
+
     def getNfolds(self):
         value = self._java_obj.getNfolds()
         return value
@@ -288,3 +308,6 @@ class H2OGBMMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneConstrai
     def getAucType(self):
         value = self._java_obj.getAucType()
         return value
+
+    # Outputs
+
