@@ -127,6 +127,13 @@ class H2OMOJOModelParams:
         """:return: Default threshold used for predictions"""
         return self._java_obj.getDefaultThreshold()
 
+    def getMojoFileName(self):
+        return self._java_obj.mojoFileName()
+
+    def getCoefficients(self):
+        return H2OTypeConverters.scalaToPythonDataFrame(self._java_obj.getCoefficients())
+
+
 class H2OAlgorithmMOJOModelParams(H2OMOJOModelParams, H2OAlgorithmMOJOModelBase):
     pass
 
